# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [2.0.1]

### Added in version 2.0.1

Nothing so far

### Changed in version 2.0.1

* Bumped the version number
* Fixed some typos in the documentation
* The license name was displayed twice on PyPI. Fixed
* Corrected `core/config.py` for PyPI distribution
* The `init` command wasn't displaying some of the files that it copied. Fixed
* Fixed bugs in the Discord, Slack, and Telegram output plugins
* Better error checking if another process is already listening to the same port
* Better Python 2.x/3.x compatibility
* Completely rewritten `Dockerfile`, uses hardened images

## [2.0.0]

### Added in version 2.0.0

* Made the project installable from PyPI
* `.gitlab-ci.yml` file to scan for secrets
* Sanity checks for the `blacklist` key in the config file
* Documentation for installing the honeypot on Windows

### Changed in version 2.0.0

* Increased the version number
* Corrected the port exposed in the `Dockerfile`
* Got rid of `getlist()`
* Improved the XMPP plugin to make it compatible with Python 2.x
* Fixed the honeypot name in the Discord documentation and in the HPFeeds and
Kafka plugins
* Updated the documentation with information how to start the honeypot at boot
time
* Fixed a bug in the PostgreSQL output plugin
* Switched to a hardened Docker image for Python.
* The depenency installation now allows you to install only the dependencies for
  the modules that you actually intend to use, instead of all of them.
* The program version now exists in a single place.

## [1.0.0]

### Added in version 1.0.0

* Initial release
* Implemented the honeypot using the Twisted framework
* Made the honeypot compatible with Python 3.x
* Config file support
* Various command-line options
* Log rotation
* Support for the `report_public_ip` config file option
* A script for starting, stopping, and restarting the honeypot
* Documentation
* Output plugin support
* Output plugins for
  * CouchDB
  * Datadog
  * Discord
  * Elasticsearch
  * HPFeeds
  * InfluxDB 2.0 (Python 3.6+ only)
  * JSON
  * Kafka
  * MongoDB
  * MySQL
  * NLCV API
  * PostgeSQL
  * Redis
  * RethinkDB
  * Slack
  * Socket
  * SQLite3
  * Syslog
  * Telegram
  * text
  * XMPP
